from index import Indexer
import jieba
import operator
import math

"""
搜索
返回结果：(相关问题,相似度)列表
搜索步骤：
    1.分词
    2.计算tf-idf,找出候选doc
    3.排序
"""


class Searcher:

    def __init__(self, index):
        self.index = index

    def search(self, query):
        term_list = []
        query = query.split()
        for entry in query:
            # 分词
            term_list.extend(jieba.cut_for_search(entry))

        # 计算tf-idf,找出候选doc
        # TF−IDF=tf∗idf
        tf_idf = {}
        for term in term_list:
            if term in self.index.inverted:
                for doc_id, fre in self.index.inverted[term].items():
                    if doc_id in tf_idf:
                        tf_idf[doc_id] += (1 + math.log10(fre)) * self.index.idf[term]
                    else:
                        tf_idf[doc_id] = (1 + math.log10(fre)) * self.index.idf[term]
        # 排序
        sorted_doc = sorted(tf_idf.items(), key=operator.itemgetter(1), reverse=True)
        print(sorted_doc)
        res = [self.index.id_doc[doc_id] for doc_id, score in sorted_doc]
        return res


if __name__ == '__main__':
    index = Indexer("docs.txt")
    searcher = Searcher(index)
    doc_list = searcher.search("云南曲靖")
    for doc in doc_list:
        print(doc.get('key'), doc.get('title'), doc.get('link'))
